@@ -4,7 +4,7 @@ echo_mime () {
 	echo -n "$i;";
 }
 
-MIMETYPES=`cat $1 | grep -v short_list_application_ids_for_ | grep "\/"`
+MIMETYPES=`cat $1`
 echo -n MimeType=;
 for i in $MIMETYPES ; do
 	echo_mime;
