@@ -15,6 +15,7 @@
 #include <unistd.h>
 #include <stdlib.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
+#include <libgnomevfs/gnome-vfs-init.h>
 
 static char*
 totem_create_full_path (const char *path)
@@ -104,6 +105,11 @@ on_got_metadata_event (BaconVideoWidget *bvw, gpointer data)
 	g_print ("CD Index: %s\n", g_value_get_string (&value));
 	g_value_unset (&value);
 
+	bacon_video_widget_get_metadata (BACON_VIDEO_WIDGET (bvw),
+			BVW_INFO_TRACK_NUMBER, &value);
+	g_print ("Track Number: %d\n", g_value_get_int (&value));
+	g_value_unset (&value);
+
 	bacon_video_widget_get_metadata (BACON_VIDEO_WIDGET (bvw),
 			BVW_INFO_HAS_VIDEO, &value);
 	has_type = g_value_get_boolean (&value);
