@@ -410,8 +410,8 @@ totem_action_load_media_device (Totem *totem, const char *device)
 
 	switch (type) {
 		case MEDIA_TYPE_ERROR:
-			totem_action_error ("Failed to play Audio/Video Disc",
-					    error ? error->message : "Reason unknown",
+			totem_action_error (_("Failed to play Audio/Video Disc"),
+					    error ? error->message : _("Reason unknown"),
 					    totem);
 			retval = FALSE;
 			break;
@@ -3339,7 +3339,7 @@ totem_volume_create (void)
 	GtkWidget *widget;
 
 	widget = bacon_volume_button_new (GTK_ICON_SIZE_SMALL_TOOLBAR,
-					  0, 100, -1);
+					  0, 100, 1);
 	gtk_widget_show (widget);
 
 	return widget;
